==> qtm-modest-plugin_0.0.2-3.tar.gz: qtm-modest-plugin-0.0.2/src/qtmm-defs.c <==
/* Copyright (c) 2010, Nokia Corporation
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * * Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 * * Neither the name of the Nokia Corporation nor the names of its
 *   contributors may be used to endorse or promote products derived from
 *   this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* System includes */
#include <glib.h>

/* For D-BUS GTypes */
#include <dbus/dbus-gtype-specialized.h>

/* Own includes */
#include "qtmm-defs.h"

/*
 * Public functions
 */

/* Type definition for a custom D-BUS type for HeadersReceived signal */
GType
qtmm_header_info_get_type (void)
{
    static GType type = 0;

    if (G_UNLIKELY (type == 0)) {
        type = dbus_g_type_get_collection (
            "GPtrArray",
            dbus_g_type_get_map (
                "GHashTable",
                G_TYPE_STRING,
                G_TYPE_VALUE));
    }

    return type;
}

==> qtm-modest-plugin_0.0.2-4.tar.gz: qtm-modest-plugin-0.0.2/src/qtmm-defs.c <==
/* Copyright (c) 2010, Nokia Corporation
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * * Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 * * Neither the name of the Nokia Corporation nor the names of its
 *   contributors may be used to endorse or promote products derived from
 *   this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* System includes */
#include <glib.h>

/* For D-BUS GTypes */
#include <dbus/dbus-gtype-specialized.h>

/* Own includes */
#include "qtmm-defs.h"

/*
 * Public functions
 */

/* Type definition for a custom D-BUS type for HeadersReceived signal */
GType
qtmm_header_info_get_type (void)
{
    static GType type = 0;

    if (G_UNLIKELY (type == 0)) {
        type = dbus_g_type_get_collection (
            "GPtrArray",
            dbus_g_type_get_map (
                "GHashTable",
                G_TYPE_STRING,
                G_TYPE_VALUE));
    }

    return type;
}

/* Type definition for a custom D-BUS type for FolderContentsChanged signal */
GType
qtmm_folder_info_get_type (void)
{
    static GType type = 0;

    if (G_UNLIKELY (type == 0)) {
        type = dbus_g_type_get_collection (
            "GPtrArray",
            G_TYPE_STRING);
    }

    return type;
}
